package com.ruoyi.project.system.service;

import com.ruoyi.project.system.domain.QuoteLog;

import java.util.List;

/**
 * 查询日志Service接口
 *
 * @author zhu
 * @date 2023-11-07
 */
public interface IQuoteLogService {
    /**
     * 查询查询日志
     *
     * @param id 查询日志主键
     * @return 查询日志
     */
    public QuoteLog selectQuoteLogById(Long id);

    /**
     * 查询查询日志列表
     *
     * @param quoteLog 查询日志
     * @return 查询日志集合
     */
    public List<QuoteLog> selectQuoteLogList(QuoteLog quoteLog);

    /**
     * 新增查询日志
     *
     * @param quoteLog 查询日志
     * @return 结果
     */
    public int insertQuoteLog(QuoteLog quoteLog);

    /**
     * 修改查询日志
     *
     * @param quoteLog 查询日志
     * @return 结果
     */
    public int updateQuoteLog(QuoteLog quoteLog);

    /**
     * 批量删除查询日志
     *
     * @param ids 需要删除的查询日志主键集合
     * @return 结果
     */
    public int deleteQuoteLogByIds(Long[] ids);

    /**
     * 删除查询日志信息
     *
     * @param id 查询日志主键
     * @return 结果
     */
    public int deleteQuoteLogById(Long id);

    public void select();
}
